@@ -38,6 +38,7 @@
 #include "lxappearance/lxappearance.h"
 
 #include <gdk/gdkx.h>
+#include <libxml/xmlsave.h>
 
 GtkWidget *mainwin = NULL;
 
@@ -157,14 +158,22 @@ extern gboolean plugin_load(LXAppearance* app, GtkBuilder* lxappearance_builder)
     if(app->abi_version > LXAPPEARANCE_ABI_VERSION)
         return FALSE;
 
+    GdkScreen *screen = gtk_widget_get_screen(app->dlg);
+
+#if GTK_CHECK_VERSION(3, 0, 0)
+    if(!GDK_IS_X11_SCREEN(screen))
+        return FALSE;
+#endif
+
     /* detect openbox */
-    const char* wm_name = gdk_x11_screen_get_window_manager_name(gtk_widget_get_screen(app->dlg));
+    const char* wm_name = gdk_x11_screen_get_window_manager_name(screen);
     if(g_strcmp0(wm_name, "Openbox"))
         return FALSE; /* don't load the plugin if openbox is not in use. */
 
 #ifdef ENABLE_NLS
     bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+    textdomain(GETTEXT_PACKAGE);
 #endif
 
     mainwin = app->dlg;
